@@ -19,18 +19,7 @@
 
 #include <ags/audio/pulse/ags_pulse_client.h>
 
-#include <ags/util/ags_id_generator.h>
-
-#include <ags/object/ags_application_context.h>
-#include <ags/object/ags_distributed_manager.h>
-#include <ags/object/ags_main_loop.h>
-#include <ags/object/ags_connectable.h>
-#include <ags/object/ags_distributed_manager.h>
-#include <ags/object/ags_soundcard.h>
-#include <ags/object/ags_sequencer.h>
-
-#include <ags/thread/ags_mutex_manager.h>
-#include <ags/thread/ags_task_thread.h>
+#include <ags/libags.h>
 
 #include <ags/audio/ags_sound_provider.h>
 #include <ags/audio/ags_channel.h>
@@ -39,6 +28,7 @@
 #include <ags/audio/pulse/ags_pulse_server.h>
 #include <ags/audio/pulse/ags_pulse_port.h>
 #include <ags/audio/pulse/ags_pulse_devout.h>
+#include <ags/audio/pulse/ags_pulse_devin.h>
 
 #include <ags/i18n.h>
 
@@ -665,6 +655,7 @@ ags_pulse_client_open(AgsPulseClient *pulse_client,
     pa_context_set_state_callback(pulse_client->context,
 				  ags_pulse_client_state_callback,
 				  pulse_client);
+#if 0
     ready = FALSE;
     
     while(!ready){
@@ -680,6 +671,7 @@ ags_pulse_client_open(AgsPulseClient *pulse_client,
 			    NULL);
       }
     }
+#endif
 #endif
   }
 }
@@ -765,7 +757,7 @@ ags_pulse_client_deactivate(AgsPulseClient *pulse_client)
 /**
  * ags_pulse_client_add_device:
  * @pulse_client: the #AgsPulseClient
- * @pulse_device: an #AgsPulseDevout or #AgsPulseMidiin
+ * @pulse_device: an #AgsPulseDevout or #AgsPulseDevin
  *
  * Add @pulse_device to @pulse_client.
  *
@@ -776,8 +768,8 @@ ags_pulse_client_add_device(AgsPulseClient *pulse_client,
 			    GObject *pulse_device)
 {
   if(!AGS_IS_PULSE_CLIENT(pulse_client) ||
-     (!AGS_IS_PULSE_DEVOUT(pulse_device) /* &&
-       !AGS_IS_PULSE_MIDIIN(pulse_device) */)){
+     (!AGS_IS_PULSE_DEVOUT(pulse_device) &&
+      !AGS_IS_PULSE_DEVIN(pulse_device))){
     return;
   }
 
@@ -789,7 +781,7 @@ ags_pulse_client_add_device(AgsPulseClient *pulse_client,
 /**
  * ags_pulse_client_remove_device:
  * @pulse_client: the #AgsPulseClient
- * @pulse_device: an #AgsPulseDevout or #AgsPulseMidiin
+ * @pulse_device: an #AgsPulseDevout or #AgsPulseDevin
  *
  * Remove @pulse_device from @pulse_client.
  *
